%%%%%%%%%%%%%
% Code to generate plots shown in Figure 1 for
% "Invariant Odor Recognition with ON-OFF Neural Ensembles"
% Authors:Srinath Nizampatnam, Lijun Zhang, Rishabh Chandak, James Li, Barani Raman
% Washington University in St. Louis
% Code written by: Rishabh Chandak
% Version current as of: December 10, 2021
% doi: 10.1073/pnas.2023340119
%%%%%%%%%%%%%

%% Figure 1B
%Load the data
load('hex_durations_data.mat')
%Process data
data = POR.hex750ms;
backstart = 6;
fps = 30;
dur = 12;
m = mean(data,1);
s = std(data,1)/sqrt(size(data,1));
time = 1/fps:1/fps:dur;
y = m(backstart*fps+1:(backstart+dur)*fps);
s = s(backstart*fps+1:(backstart+dur)*fps);
%Generate plot
figure
plot(time,y,'b','linewidth',2)
lineprops.col = {'r'};
mseb(time,y,s,lineprops)
ylabel('Palp separation (a.u.)')
r1 = rectangle('Position',[2,0,0.75,20],'FaceColor','r');
uistack(r1,'bottom')
ylim([0 20])
xticklabels([])
xticks([])
%%
%Process data
data = POR.hex10s;
backstart = 8;
fps = 25;
dur = 20;
m = mean(data,1);
s = std(data,1)/sqrt(size(data,1));
time = 1/fps:1/fps:dur;
y = m(backstart*fps+1:(backstart+dur)*fps);
s = s(backstart*fps+1:(backstart+dur)*fps);

%Generate plot
figure
plot(time,y,'b','linewidth',2)
lineprops.col = {'r'};
mseb(time,y,s,lineprops)
ylabel('Palp separation (a.u.)')
r1 = rectangle('Position',[2,0,10,30],'FaceColor','r');
uistack(r1,'bottom')
ylim([0 30])
xticklabels([])
xticks([])

%%
%Load the data
load('hex_pulses_data.mat')
%Process data
data = POR.hex2s;
backstart = 8;
fps = 30;
dur = 12;
m = mean(data,1);
s = std(data,1)/sqrt(size(data,1));
time = 1/fps:1/fps:dur;
y = m(backstart*fps+1:(backstart+dur)*fps);
s = s(backstart*fps+1:(backstart+dur)*fps);

%Generate plot
figure
plot(time,y,'b','linewidth',2)
lineprops.col = {'r'};
mseb(time,y,s,lineprops)
ylabel('Palp separation (a.u.)')
r1 = rectangle('Position',[2,0,2,18],'FaceColor','r');
uistack(r1,'bottom')
r2 = rectangle('Position',[6,0,2,18],'FaceColor','r');
uistack(r2,'bottom')
ylim([0 18])
xticklabels([])
xticks([])

%% Figure 1C
%Load the data
load('flex_coding_data.mat')

%Process and plot data
figure
data = ben;
backstart = 13;
fps = 30;
dur = 20;
m = mean(data,1);
s = std(data,1)/sqrt(size(data,1));
time = 1/fps:1/fps:dur;
y = m(backstart*fps+1:(backstart+dur)*fps);
y = y-mean(y(1:100))+1;
s = s(backstart*fps+1:(backstart+dur)*fps);
plot(time,y,'b','linewidth',2)
lineprops.col = {'r'};
mseb(time,y,s,lineprops)
ylabel('Palp separation (a.u.)')
r1 = rectangle('Position',[2,0,4,25],'FaceColor','b');
uistack(r1,'bottom')
r2 = rectangle('Position',[6.5,0,4,25],'FaceColor','r');
uistack(r2,'bottom')
ylim([0 25])
xticklabels([])
xticks([])

figure
data = cit;
backstart = 13;
fps = 30;
dur = 20;
m = mean(data,1);
s = std(data,1)/sqrt(size(data,1));
time = 1/fps:1/fps:dur;
y = m(backstart*fps+1:(backstart+dur)*fps);
y = y-mean(y(1:100))+1;
s = s(backstart*fps+1:(backstart+dur)*fps);
plot(time,y,'b','linewidth',2)
lineprops.col = {'r'};
mseb(time,y,s,lineprops)
ylabel('Palp separation (a.u.)')
r1 = rectangle('Position',[2,0,4,25],'FaceColor','b');
uistack(r1,'bottom')
r2 = rectangle('Position',[6.5,0,4,25],'FaceColor','r');
uistack(r2,'bottom')

ylim([0 25])
xticklabels([])
xticks([])
%% Figure 1D
%Load the data
load('IaaBzaldForeBack.mat')
%Process and plot data
figure
data = SingleOdor_trained;
backstart = 8;
fps = 10;
dur = 10;
m = mean(data,1);
s = std(data,1)/sqrt(size(data,1));
time = 1/fps:1/fps:dur;
y = m(backstart*fps+1:(backstart+dur)*fps);
s = s(backstart*fps+1:(backstart+dur)*fps);
plot(time,y,'b','linewidth',2)
lineprops.col = {'r'};
mseb(time,y,s,lineprops)
ylabel('Palp separation (a.u.)')
r1 = rectangle('Position',[2,0,4,60],'FaceColor','b');
uistack(r1,'bottom')
ylim([0 60])
xticklabels([])
xticks([])
hold on

data = SingleOdor_untrained;
backstart = 8;
fps = 10;
dur = 10;
m = mean(data,1);
s = std(data,1)/sqrt(size(data,1));
time = 1/fps:1/fps:dur;
y = m(backstart*fps+1:(backstart+dur)*fps);
s = s(backstart*fps+1:(backstart+dur)*fps);
plot(time,y,'b','linewidth',2)
lineprops.col = {'b'};
mseb(time,y,s,lineprops)
ylabel('Palp separation (a.u.)')
r1 = rectangle('Position',[2,0,4,60],'FaceColor','b');
uistack(r1,'bottom')
ylim([0 60])
xticklabels([])
xticks([])

figure
hold on
data = overlapping_2s;
backstart = 8;
fps = 10;
dur = 12;
m = mean(data,1);
s = std(data,1)/sqrt(size(data,1));
time = 1/fps:1/fps:dur;
y = m(backstart*fps+1:(backstart+dur)*fps);
s = s(backstart*fps+1:(backstart+dur)*fps);
plot(time,y,'r','linewidth',2)
lineprops.col = {'b'};
ylabel('Palp separation (a.u.)')
r1 = rectangle('Position',[2,0,10,50],'FaceColor','b');
uistack(r1,'bottom')
r2 = rectangle('Position',[4,0,4,50],'FaceColor','r');
mseb(time,y,s,lineprops)
ylim([0 50])
xticklabels([])
xticks([])

figure
hold on
data = overlapping_4s;
backstart = 8;
fps = 10;
dur = 12;
m = mean(data,1);
s = std(data,1)/sqrt(size(data,1));
time = 1/fps:1/fps:dur;
y = m(backstart*fps+1:(backstart+dur)*fps);
s = s(backstart*fps+1:(backstart+dur)*fps);
plot(time,y,'r','linewidth',2)
lineprops.col = {'b'};

ylabel('Palp separation (a.u.)')
r1 = rectangle('Position',[2,0,10,50],'FaceColor','b');
uistack(r1,'bottom')
r2 = rectangle('Position',[6,0,4,50],'FaceColor','r');
mseb(time,y,s,lineprops)
ylim([0 50])
xticklabels([])
xticks([])

%% Figure 1E
%Load the data
load('dry_training_data.mat')
%Process and plot data
figure
hold on
data = Hexanol_1Dry;
backstart = 7.5;
fps = 30;
dur = 10;
m = mean(data,1);
s = std(data,1)/sqrt(size(data,1));
time = 1/fps:1/fps:dur;
y = m(backstart*fps+1:(backstart+dur)*fps);
s = s(backstart*fps+1:(backstart+dur)*fps);
plot(time,y,'r','linewidth',2)
lineprops.col = {'r'};
mseb(time,y,s,lineprops)
ylabel('Palp separation (a.u.)')
r1 = rectangle('Position',[2,0,4,20],'FaceColor','r');
uistack(r1,'bottom')

hold on
data = Hexanol_1Humid;
backstart = 7.5;
fps = 30;
dur = 10;
m = mean(data,1);
s = std(data,1)/sqrt(size(data,1));
time = 1/fps:1/fps:dur;
y = m(backstart*fps+1:(backstart+dur)*fps);
s = s(backstart*fps+1:(backstart+dur)*fps);
plot(time,y,'r','linewidth',2)
lineprops.col = {'b'};
mseb(time,y,s,lineprops)
xticklabels([])
xticks([])

%Load the data
load('humid_training_data.mat')

figure
hold on
data = Hexanol_1Dry;
backstart = 8;
fps = 30;
dur = 10;
m = mean(data,1);
s = std(data,1)/sqrt(size(data,1));
time = 1/fps:1/fps:dur;
y = m(backstart*fps+1:(backstart+dur)*fps);
s = s(backstart*fps+1:(backstart+dur)*fps);
plot(time,y,'r','linewidth',2)
lineprops.col = {'r'};
mseb(time,y,s,lineprops)
ylabel('Palp separation (a.u.)')
r1 = rectangle('Position',[2,0,4,25],'FaceColor','b');
uistack(r1,'bottom')

hold on
data = Hexanol_1Humid;
backstart = 8;
fps = 30;
dur = 10;
m = mean(data,1);
s = std(data,1)/sqrt(size(data,1));
time = 1/fps:1/fps:dur;
y = m(backstart*fps+1:(backstart+dur)*fps);
s = s(backstart*fps+1:(backstart+dur)*fps);
plot(time,y,'r','linewidth',2)
lineprops.col = {'b'};
mseb(time,y,s,lineprops);
xticklabels([])
xticks([])