function H = mseb(x,y,errBar,lineProps,transparent)
%% Error checking
error(nargchk(3,5,nargin))

% Cheking the y data
[C, N] = size(y);
if N==1
    C = 1;
    N = length(y);
    y = y';
end

% Cheking the x data
if isempty(x)
    x=repmat(1:N,[C,1]);
elseif length(x(:))==N && C>1
    x=repmat(x(:)',[C,1]);
end

if (size(x,1) ~= C) || (size(x,2)~=N)
    error('inputs x and y do not have same dimensions')
end

% Checking ErrBar dimensions. If only one error bar is specified then we
% will mirror it, turning it into both upper and lower bars.
if (size(errBar,1) ~= C) || (size(errBar,2)~=N)
    if size(errBar,1)==N && size(errBar,2)==2 && size(errBar,3)~=1 && C==1
        errBar = permute(errBar,[3,1,2]);
    elseif size(errBar,1)==N && size(errBar,2)==1 && size(errBar,3)~=1 && C==1
        errBar=repmat(errBar,[1,2]);
        errBar = permute(errBar,[3,1,2]);
    else
        error('inputs errBar and y do not have same dimensions')
    end
end
if size(errBar,3)==1
    errBar = repmat(errBar,[1,1,2]);
end


%% Setting default line options
if nargin<4
    lineProps = [];
end
if nargin<5 || ~isnumeric(transparent)
    transparent=0;
end
if ~isfield(lineProps,'col')
    for c = 1:C
        colours = 'brkgmcy';
        col_ind = rem(c-1,length(colours))+1;
        lineProps.col{c} = colours(col_ind);
    end
end
if ~isfield(lineProps,'style'),	lineProps.style = '-'; end
if ~isfield(lineProps,'width'),	lineProps.width = 2; end
if ~isfield(lineProps,'edgestyle'),	lineProps.edgestyle = '--'; end

%% First loop over the number of lines to be plotted
% (More or less contains the original code from shadedErrorBar)
holdStatus=ishold;
if ~holdStatus, hold on,  end

for c = C:-1:1
    %% Plotting patches
    % Plot the main line. We plot this first in order to extract the RGB values
    % for the line colour. I am not aware of a function that does this.
    H(c).mainLine=plot(x(c,:),y(c,:),'color',lineProps.col{c});
    
    
    % Work out the color of the shaded region and associated lines
    % Using alpha requires the render to be openGL and so you can't
    % save a vector image. We therefore provide the option of choosing alpha
    % or a de-saturated solid colour for the patch surface.
    
    col=get(H(c).mainLine,'color');
    edgeColor=col+(1-col)*0.55;
    patchSaturation=0.15; %How de-saturated or transparent to make the patch
    if transparent
        faceAlpha=patchSaturation;
        patchColor=col;
        set(gcf,'renderer','openGL')
    else
        faceAlpha=1;
        patchColor=col+(1-col)*(1-patchSaturation);
        set(gcf,'renderer','painters')
    end
    
    %Calculate the y values at which we will place the error bars
    uE=y(c,:)+errBar(c,:,1);
    lE=y(c,:)-errBar(c,:,2);
    
    %Make the cordinats for the patch
    yP=[lE,fliplr(uE)];
    xP=[x(c,:),fliplr(x(c,:))];
    
    %remove any nans otherwise patch won't work
    xP(isnan(yP))=[];
    yP(isnan(yP))=[];
    
    
    H(c).patch=patch(xP,yP,1,'facecolor',patchColor,...
        'edgecolor','none',...
        'facealpha',faceAlpha);
    
    
    %Make nice edges around the patch.
    H(c).edge(1)=plot(x(c,:),lE,'-','color',edgeColor);
    H(c).edge(2)=plot(x(c,:),uE,'-','color',edgeColor);
end

%% Second loop over the number of lines to be plotted
for c = C:-1:1
    %% Plot egdes for patchoverlaps
    col=get(H(c).mainLine,'color');
    edgeColor=col+(1-col)*0.55;
    lE = get(H(c).edge(1), 'ydata');
    uE = get(H(c).edge(2), 'ydata');
    
    H(c).edgeoverlap(1)=plot(x(c,:),lE,lineProps.edgestyle,'color',edgeColor);
    H(c).edgeoverlap(2)=plot(x(c,:),uE,lineProps.edgestyle,'color',edgeColor);
    
end

%% Third loop over the number of lines to be plotted
for c = 1:C
    %% Plot mainlines
    %The main line is now covered by the patch object and was plotted first to
    %extract the RGB value of the main plot line. I am not aware of an easy way
    %to change the order of plot elements on the graph so we'll just remove it
    %and put it back (yuk!)
    delete(H(c).mainLine)
    H(c).mainLine=plot(x(c,:),y(c,:),lineProps.style,'color',lineProps.col{c},...
        'linewidth',lineProps.width);
    
    
    %% Turn legendinformation off for all but the main lines
    set(get(get(H(c).patch,'Annotation'),'LegendInformation'),'IconDisplayStyle','off')
    set(get(get(H(c).edge(1),'Annotation'),'LegendInformation'),'IconDisplayStyle','off')
    set(get(get(H(c).edge(2),'Annotation'),'LegendInformation'),'IconDisplayStyle','off')
    set(get(get(H(c).edgeoverlap(1),'Annotation'),'LegendInformation'),'IconDisplayStyle','off')
    set(get(get(H(c).edgeoverlap(2),'Annotation'),'LegendInformation'),'IconDisplayStyle','off')
    set(get(get(H(c).mainLine,'Annotation'),'LegendInformation'),'IconDisplayStyle','on')
    
end
if ~holdStatus, hold off, end

