%%%%%%%%%%%%%
% Code to generate plots shown in Figure 2 for
% "Invariant Odor Recognition with ON-OFF Neural Ensembles"
% Authors:Srinath Nizampatnam, Lijun Zhang, Rishabh Chandak, James Li, Barani Raman
% Washington University in St. Louis
% Code written by: Rishabh Chandak
% Version current as of: December 10, 2021
% doi: 10.1073/pnas.2023340119
%%%%%%%%%%%%%

%% 2A
%%%%%%%%%%
% Throughout this code commented sections are used to
% get values across different data sets.
% They do not need to be run to generate the figures
%%%%%%%%%%%

% load('flex_coding_data.mat')
% odors = flip(who);
% fractions = zeros(size(odors,1),1);
% for i = 1:size(odors,1)
%
% eval(sprintf('data = %s;',odors{i}))
% base_start = 13;
% sig = 6.5;
%
% odor_dur = 4;
% fps = 30;
% fraction = 0.25;
%
% if strcmp(odors{i},'pure_hex')
%     odor_start = 19.5;
% else
%     odor_start = 15;
% end
% fractions(i) = getResponsiveCount(data,base_start,sig,odor_start,odor_dur,fps,fraction);
% end
% fractions = fractions / size(pure_hex,1)*100;
% [a,b] = sort(fractions,'descend');
% odors = odors(b);
% x = categorical(odors);
% x = reordercats(x,string(x));
% figure
% b = bar(x,a,'k')
% ylabel("Percent responsive (%)")
%
%
% load('flex_coding_rebuttal_data.mat')
% odors = flip(who);
% fractions = zeros(size(odors,1),1);
% for i = 1:size(odors,1)
%
% eval(sprintf('data = %s;',odors{i}))
% base_start = 8;
% sig = 6.5;
% odor_dur = 4;
% fps = 30;
% fraction = 0.25;
% if strcmp(odors{i},'hex')
%     odor_start = 14.5;
% else
%     odor_start = 10;
% end
% fractions(i) = getResponsiveCount(data,base_start,sig,odor_start,odor_dur,fps,fraction);
% end
% fractions = fractions / size(hex,1)*100;
% [a,b] = sort(fractions,'descend');
% odors = odors(b);
% x = categorical(odors);
% x = reordercats(x,string(x));
% figure
% b = bar(x,a,'k');
% ylabel("Percent responsive (%)")

%data obtained from above parts is combined and plotted:
f1 = [25;23;21;5;3;2]/27; %n = 27
o1 = {'pure_hex';'oct';'iaa';'cit';'ben';'app'};
f2 = [19;4;3;2;2;1]/20; %n = 20
o2 = {'hex';'Lcarv_hex';'neem_hex';'ger_hex';'chex_hex';'msal_hex'};
h = (25+19)/(47);
f_comb = cat(1,h,f1(2:end),f2(2:end));
o_comb = {'hex','oct','iaa','cit','ben','app','Lcarv','neem','ger','chex','msal'};

[a,b] = sort(f_comb,'descend');

x = categorical(o_comb);
x = reordercats(x,string(x));
figure
bar(x,a,'k')
ylabel('Probability of POR')
title('Figure 2A')
%% 2B
% clear
% clc
% % close all
% load('hex_pulses_data.mat')
% odors = flip(fieldnames(POR));
% fractions = zeros(size(odors,1),1);
% for i = 1:size(odors,1)
%
% eval(sprintf('data = POR.%s;',odors{i}))
% base_start = 8;
% sig = 6.5;
%
% odor_dur = 8;
% fps = 30;
% fraction = 0.25;
% odor_start = 10;
% fractions(i) = getResponsiveCount(data,base_start,sig,odor_start,odor_dur,fps,fraction);
% end
% fractions = fractions /27*100;
% [a,b] = sort(fractions,'descend');
% odors = odors(b);
% x = categorical(odors);
% x = reordercats(x,string(x));
% figure
% bar(x,a)
% ylabel("Percent responsive")

% clear
% clc
% % close all
% load('hex_durations_data.mat')
% odors = flip(fieldnames(POR));
% fractions = zeros(size(odors,1),1);
% for i = 1:size(odors,1)
%
% eval(sprintf('data = POR.%s;',odors{i}))
% base_start = 6;
% sig = 6.5;
%
% odor_dur = 4;
% fps = 30;
% fraction = 0.25;
% odor_start = 8;
% fractions(i) = getResponsiveCount(data,base_start,sig,odor_start,odor_dur,fps,fraction);
% end
% fractions = fractions /30*100;
% [a,b] = sort(fractions,'descend');
% odors = odors(b);
% x = categorical(odors);
% x = reordercats(x,string(x));
% figure
% bar(x,a)
% ylabel("Percent responsive")
% %hex10 = 86.87, 750ms = 76.67 ,2s2s = 100%

%data obtained from above parts is combined and plotted:
figure
x = categorical({'750ms','10s','2s_2s',});
x = reordercats(x,string(x));
bar(x,[77,86.8,100 ],'k','barwidth',0.3)
ylabel("Percent responsive")
ylim([0 105])
title('Figure 2B')
%% 2C
clear
clc
load('IaaBzaldForeBack.mat')
odors = flip(who);
fractions = zeros(size(odors,1),1);
for i = 1:size(odors,1)
    
    eval(sprintf('data = %s;',odors{i}))
    base_start = 8;
    sig = 6.5;
    odor_dur = 8;
    fps = 10;
    fraction = 0.25;
    odor_start = 10;
    fractions(i) = getResponsiveCount(data,base_start,sig,odor_start,odor_dur,fps,fraction);
end
fractions = fractions / size(SingleOdor_trained,1)*100;
[a,b] = sort(fractions,'descend');
odors = odors(b);
x = categorical(odors);
x = reordercats(x,string(x));
figure
bar(x,a, 'k','BarWidth', 0.4)
ylim([0 105])
ylabel("Percent responsive (%)")
title('Figure 2C')
%% 2D
% clear
% clc
% close all
% load('flex_coding_data.mat')
% odors = flip(who);
% fractions = zeros(size(odors,1),1);
% for i = 1:size(odors,1)
%
% eval(sprintf('data = %s;',odors{i}))
% base_start = 13;
% sig = 6.5;
%
% odor_dur = 4;
% fps = 30;
% fraction = 0.25;
%
% odor_start = 19.5
% fractions(i) = getResponsiveCount(data,base_start,sig,odor_start,odor_dur,fps,fraction);
% end
% fractions = fractions / size(pure_hex,1)*100;
% [a,b] = sort(fractions,'descend');
% odors = odors(b);
% x = categorical(odors);
% x = reordercats(x,string(x));
% figure
% bar(x,a,'k')
% ylabel("Percent responsive (%)")
%
% load('flex_coding_rebuttal_data.mat')
% odors = flip(who);
% fractions = zeros(size(odors,1),1);
% for i = 1:size(odors,1)
%
% eval(sprintf('data = %s;',odors{i}))
% base_start = 8;
% sig = 6.5;
% odor_dur = 4;
% fps = 30;
% fraction = 0.25;
% odor_start = 14.5;
% fractions(i) = getResponsiveCount(data,base_start,sig,odor_start,odor_dur,fps,fraction);
% end
% fractions = fractions / size(hex,1)*100;
% [a,b] = sort(fractions,'descend');
% odors = odors(b);
% x = categorical(odors);
% x = reordercats(x,string(x));
% figure
% bar(x,a,'k')
% ylabel("Percent responsive (%)")

%data obtained from above parts is combined and plotted:

f1 = [25;27;26;24;23]/27; %n = 27 locusts
o1 = {'oct';'cit';'iaa';'ben';'app'};
f2 = [19;19;19;18;19]/20; %n = 20 locusts
o2 = {'neem_hex';'ger_hex';'Lcarv_hex';'chex_hex';'msal_hex'};

f_comb = cat(1,f1,f2);
o_comb = {'oct';'cit';'iaa';'ben';'app';'neem';'ger';'Lcarv';'chex';'msal'};
[a,b] = sort(f_comb,'descend');
x = categorical(o_comb);
x = reordercats(x,string(x));
figure
bar(x,a,'k')
ylabel('Probability of Hexanol POR')
xlabel('Stimulus history')
ylim([0 1.02])
title('Figure 2D')
%% 2E
clear
clc
load('dry_training_data.mat')
odors = {'Hexanol_1Dry';'Hexanol_1Humid'};
fractions = zeros(size(odors,1),1);
for i = 1:size(odors,1)
    
    eval(sprintf('data = %s;',odors{i}))
    base_start = 8;
    sig = 6.5;
    
    odor_dur = 4;
    fps = 30;
    fraction = 0.25;
    odor_start = 10;
    fractions(i) = getResponsiveCount(data,base_start,sig,odor_start,odor_dur,fps,fraction);
end

fractions = fractions / size(Hexanol_1Dry,1)*100;
[a,b] = sort(fractions,'descend');
odors = odors(b);
x = categorical(odors);
x = reordercats(x,string(x));
figure
bar(x,a, 'k','BarWidth', 0.2)
ylim([0 90])
ylabel("Percent responsive (%)")
title('Figure 2E')

load('humid_training_data.mat')
odors = {'Hexanol_1Dry';'Hexanol_1Humid'};
fractions = zeros(size(odors,1),1);
for i = 1:size(odors,1)
    eval(sprintf('data = %s;',odors{i}))
    base_start = 8;
    sig = 6.5;
    odor_dur = 4;
    fps = 30;
    fraction = 0.25;
    odor_start = 10;
    fractions(i) = getResponsiveCount(data,base_start,sig,odor_start,odor_dur,fps,fraction);
end


fractions = fractions / size(Hexanol_1Dry,1)*100;
[a,b] = sort(fractions,'descend');
odors = odors(b);
x = categorical(odors);
x = reordercats(x,string(x));
figure
bar(x,a, 'k','BarWidth', 0.2)
ylim([0 105])
ylabel("Percent responsive (%)")
title('Figure 2E')