%%%%%%%%%%%%%
% Code to generate plots shown in Figure 4 for
% "Invariant Odor Recognition with ON-OFF Neural Ensembles"
% Authors:Srinath Nizampatnam, Lijun Zhang, Rishabh Chandak, James Li, Barani Raman
% Washington University in St. Louis
% Code written by: Srinath Nizampatnam, Lijun Zhang
% Version current as of: December 10, 2021
% doi: 10.1073/pnas.2023340119
%%%%%%%%%%%%%
clear,clc
close all

load('..\data\PNs_iaa.mat');
load('..\data\PNs_hex.mat');
load('StimulusProtocol.txt');
Stim = StimulusProtocol;

for nn=1:length(iaa_4s)
    data_iaa(nn,:,:) = (iaa_4s{1,nn})';
    data_iaa_dry(nn,:,:) = (iaa_dry{1,nn})';
    data_iaa_humid(nn,:,:) = (iaa_humid{1,nn})';
    data_hex(nn,:,:) = (hex_4s{1,nn})';
    data_hex_dry(nn,:,:) = (hex_dry{1,nn})';
    data_hex_humid(nn,:,:) = (hex_humid{1,nn})';    
end

mean_iaa = mean(data_iaa, 3);
mean_iaa_dry = mean(data_iaa_dry, 3);
mean_iaa_humid = mean(data_iaa_humid, 3);

mean_hex = mean(data_hex, 3);
mean_hex_dry = mean(data_hex_dry, 3);
mean_hex_humid = mean(data_hex_humid, 3);

hex_pulses_times=[];
for ss=1:11
    st = Stim(ss,2)/50;
    dr = Stim(ss,3)/50; 
    hex_pulses_times = [hex_pulses_times, st+1:st+dr];
end
%%
%% Correlations for dry and humid
data_dry = data_hex_dry;
data_humid = data_hex_humid;
% Uncomment these to plot for iaa
% data_dry = data_iaa_dry;
% data_humid = data_iaa_humid;
data_dry_mean = mean(data_dry,3);
data_humid_mean = mean(data_humid,3);

Cfs=[];
Cfs_humid=[];
for nn=1:size(data_dry_mean,1)
    pulses_dry=[];
    pulses_humid=[];
    for ss = 1:11
        st = 20*Stim(ss,2)/1000;
        dr = 20*Stim(ss,3)/1000;
        pulse_mean=data_dry_mean(nn,st+1:st+20);
        pulse_mean_humid=data_humid_mean(nn,st+1:st+20);
        pulses_dry=[pulses_dry;pulse_mean];
        pulses_humid = [pulses_humid; pulse_mean_humid];
    end
    if nn==56 %Example PN in figure
        count=56;
    end
    pc=corrcoef(pulses_dry');
    pch=corrcoef(pulses_humid');
    Cfs = [Cfs,mean(pc(1,2:end))];
    Cfs_humid = [Cfs_humid,mean(pch(1, 2:end))];
end

nanlogic = any(isnan([Cfs;Cfs_humid]), 1);

Cfs = Cfs(~nanlogic);
Cfs_humid = Cfs_humid(~nanlogic);
significance = kstest2(Cfs, Cfs_humid)

figure;hold on;
histogram(Cfs,20, 'FaceColor', 'red','EdgeColor','none');
histogram(Cfs_humid,20, 'FaceColor', 'blue','EdgeColor','none');
legend('dry','humid')
xlim([-0.5,1]);
ylim([0,10]);
xlabel('Mean correlation with the first pulse response');
ylabel('#Neurons');


%% comparing hex humid and dry

hex_pulses_dry = mean_hex_dry(:,hex_pulses_times);
hex_pulses_humid = mean_hex_humid(:,hex_pulses_times);
[coeff, scores, latent] = pca([hex_pulses_dry]'); %hex_pulses_humid
[v] = latent(1:3)/sum(latent);
figure; hold on; grid on;
v1 = round(v(1)*10000)/100;
v2 = round(v(2)*10000)/100;
v3 = round(v(3)*10000)/100;


st1 = strcat('PC1 (',num2str(v1),'%)');
st2 = strcat('PC2 (',num2str(v2),'%)');
st3 = strcat('PC3 (',num2str(v3),'%)');
xlabel(st1);
ylabel(st2);
zlabel(st3);
dry_pca = scores(1:length(hex_pulses_times),1:3);
humid_pca = hex_pulses_humid'*coeff;
% humid_pca = scores(length(hex_pulses_times)+1:end,1:3);
h1 = plot3(dry_pca(:,1),dry_pca(:,2),dry_pca(:,3),'ro');
set(h1, 'markerfacecolor', get(h1, 'color'));
h1 = plot3(humid_pca(:,1),humid_pca(:,2),humid_pca(:,3),'bo');
set(h1, 'markerfacecolor', get(h1, 'color'));
view(16,56)
%% Plotting individual pulses
hex_data_pca = mean_hex_dry'*coeff;
figure;hold on;
for ss=1:11
    st = Stim(ss,2)/50;
    dr = Stim(ss,3)/50; 
    h1 = plot3(hex_data_pca(st+1:st+dr,1),hex_data_pca(st+1:st+dr,2),...
        hex_data_pca(st+1:st+dr,3), 'o', 'LineWidth', 3);
    set(h1, 'markerfacecolor', get(h1, 'color'));
end
grid on
view(22,57)