%%%%%%%%%%%%%
% Code to generate plots shown in Figure 3 for
% "Invariant Odor Recognition with ON-OFF Neural Ensembles"
% Authors:Srinath Nizampatnam, Lijun Zhang, Rishabh Chandak, James Li, Barani Raman
% Washington University in St. Louis
% Code written by: Srinath Nizampatnam, Lijun Zhang
% Version current as of: December 10, 2021
% doi: 10.1073/pnas.2023340119
%%%%%%%%%%%%%
clear,clc
close all
filepath = '..\.\data\';
load([filepath,'PNs_hex.mat']);
load([filepath,'PNs_iaa.mat']); %Load this data for 
load('StimulusProtocol.txt');
Stim = StimulusProtocol;

for nn=1:length(hex_4s)
    data_hex_4s(nn,:,:) = (hex_4s{1,nn})';
    data_hex_dry(nn,:,:) = (hex_dry{1,nn})';
    data_hex_humid(nn,:,:) = (hex_humid{1,nn})';
end

for nn=1:length(iaa_4s)
    data_iaa_4s(nn,:,:) = (iaa_4s{1,nn})';
    data_iaa_dry(nn,:,:) = (iaa_dry{1,nn})';
    data_iaa_humid(nn,:,:) = (iaa_humid{1,nn})';
end

data_dry = data_hex_dry;
data_humid = data_hex_humid;


data_dry_mean = mean(data_dry,3);
data_humid_mean = mean(data_humid,3);


%% Correlations for hex and iaa
Cfs=[];
Cfs_humid=[];
for nn=1:size(data_dry_mean,1)
    pulses_dry=[];
    pulses_humid=[];
    for ss = 1:11
        st = 20*Stim(ss,2)/1000;
        dr = 20*Stim(ss,3)/1000;
        pulse_mean=data_dry_mean(nn,st+1:st+20);
        pulse_mean_humid=data_humid_mean(nn,st+1:st+20);
        pulses_dry=[pulses_dry;pulse_mean];
        pulses_humid = [pulses_humid; pulse_mean_humid];
    end
    pc=corrcoef(pulses_dry');
    pch=corrcoef(pulses_humid');
    Cfs = [Cfs,mean(pc(1, 2:end))];
    Cfs_humid = [Cfs_humid,mean(pch(2:end))];
end
nanlogic = any(isnan([Cfs;Cfs_humid]), 1);

Cfs = Cfs(~nanlogic);
Cfs_humid = Cfs_humid(~nanlogic);
significance = kstest2(Cfs, Cfs_humid)

figure;hold on;
histogram(Cfs,20, 'FaceColor', 'red','EdgeColor','none');
xlabel('Mean correlation with the first pulse response');
xlim([-0.5,1]);
ylim([0,10]);
legend('hex')
% figure;hold on;
% histogram(Cfs_humid,20, 'FaceColor', 'blue');
% xlim([0,1]);
% ylim([0,10]);

data_dry = data_iaa_dry;
data_humid = data_iaa_humid;

data_dry_mean = mean(data_dry,3);
data_humid_mean = mean(data_humid,3);
Cfs=[];
Cfs_humid=[];
for nn=1:size(data_dry_mean,1)
    pulses_dry=[];
    pulses_humid=[];
    for ss = 1:11
        st = 20*Stim(ss,2)/1000;
        dr = 20*Stim(ss,3)/1000;
        pulse_mean=data_dry_mean(nn,st+1:st+20);
        pulse_mean_humid=data_humid_mean(nn,st+1:st+20);
        pulses_dry=[pulses_dry;pulse_mean];
        pulses_humid = [pulses_humid; pulse_mean_humid];
    end
    if nn==56 %Example PN in figure
        count=56;
    end
    pc=corrcoef(pulses_dry');
    pch=corrcoef(pulses_humid');
    Cfs = [Cfs,mean(pc(1,2:end))];
    Cfs_humid = [Cfs_humid,mean(pch(1, 2:end))];
end

nanlogic = any(isnan([Cfs;Cfs_humid]), 1);

Cfs = Cfs(~nanlogic);
Cfs_humid = Cfs_humid(~nanlogic);

figure;hold on;
histogram(Cfs,20, 'FaceColor', 'blue','EdgeColor','none');
% histogram(Cfs_humid,20, 'FaceColor', 'blue');
legend('iaa')
xlim([-0.5,1]);
ylim([0,10]);
xlabel('Mean correlation with the first pulse response');
ylabel('#Neurons');

%% PSTH
% 
tt = 0.05:0.05:60-11;
figure;hold on;

rectangle('Position', [32-11,0,8,1],'FaceColor', [0.7,0.9,0.7],'EdgeColor','none');           
rectangle('Position', [45-11,0,4,1],'FaceColor', [0.7,0.7,0.9],'EdgeColor','none');

 for ss = 1:11
     st = Stim(ss,2)/1000;
     dr = Stim(ss,3)/1000;
     rectangle('Position', [st-11,0,dr,1],'FaceColor', [0.9,0.7,0.7],'EdgeColor','none');             
 end
data_dry = data_hex_dry;
psth = squeeze(mean(data_dry(56,:,:),3));
psth = filtfilt(ones(1,5),5,psth);
plot(tt,psth(221:1200),'LineWidth',2.5);
ylim([0,0.75]);
%% fanor factor for hex
data_dry = data_hex_dry;
data_humid = data_hex_humid;
data_dry_mean = mean(data_dry,3);
data_humid_mean = mean(data_humid,3);

Cfs=[];
Cfs_humid=[];
for nn=1:size(data_dry,1)
    pulses_dry=[];
    pulses_humid=[];
    for ss = 1:11
        st = 20*Stim(ss,2)/1000;
        dr = 20*Stim(ss,3)/1000;
        pulse_mean=squeeze(sum(data_dry(nn,st+1:st+20, :), 2));
        pulse_mean_humid=squeeze(sum(data_humid(nn,st+1:st+20, :), 2));
        pulses_dry=[pulses_dry;pulse_mean];
        pulses_humid = [pulses_humid; pulse_mean_humid];
    end
    Cfs(nn) = var(pulses_dry)/mean(pulses_dry);
    Cfs_humid(nn) = var(pulses_humid)/mean(pulses_humid);
end

nanlogic = any(isnan([Cfs;Cfs_humid]), 1);

Cfs = Cfs(~nanlogic);
Cfs_humid = Cfs_humid(~nanlogic);
significance = kstest2(Cfs, Cfs_humid);

figure;hold on;
histogram(Cfs,20, 'FaceColor', 'red','EdgeColor','none');
% histogram(Cfs_humid,20, 'FaceColor', 'blue');
legend('hex')
% xlim([0,1]);
% ylim([0,20]);
xlabel('Fano Factor');
ylabel('#Neurons');

%% fanor factor for iaa
Cfs=[];
Cfs_humid=[];
data_dry=data_iaa_dry;
for nn=1:size(data_dry,1)
    pulses_dry=[];
    pulses_humid=[];
    for ss = 1:11
        st = 20*Stim(ss,2)/1000;
        dr = 20*Stim(ss,3)/1000;
        pulse_mean=squeeze(sum(data_dry(nn,st+1:st+20, :), 2));
        pulses_dry=[pulses_dry;pulse_mean];
    end
    Cfs(nn) = var(pulses_dry)/mean(pulses_dry);
end

nanlogic = any(isnan([Cfs]), 1);

Cfs = Cfs(~nanlogic);
figure;hold on;
histogram(Cfs,20, 'FaceColor', 'blue','EdgeColor','none');
legend('iaa')
% xlim([0,1]);
% ylim([0,20]);
xlabel('Fano Factor');
ylabel('#Neurons');